part of kitcod_uikit_flutter;

class FeedPostCard extends StatefulWidget {
  const FeedPostCard({
    required this.feedPost,
    required this.buildContext,
    required this.feedPostApi,
    required this.feedPostsArray,
    required this.feedGroupsArray,
    required this.profileDetailsArray,
    this.postedTimeStyle,
    this.feedTitleStyle,
    this.descriptionStyle,
    this.feedAudioTitleStyle,
    this.nameStyle,
    this.userNameStyle,
    this.groupTagsStyle,
    this.isLiked,
    final Key? key,
  }) : super(key: key);

  // -------------------------------- VARIABLES -------------------------------- //
  final FeedPost feedPost;
  final PostList feedPostApi;
  final BuildContext buildContext;
  final TextStyle? nameStyle;
  final TextStyle? groupTagsStyle;
  final TextStyle? userNameStyle;
  final TextStyle? postedTimeStyle;
  final TextStyle? feedTitleStyle;
  final TextStyle? descriptionStyle;
  final TextStyle? feedAudioTitleStyle;
  final List<FeedPost> feedPostsArray;
  final List<FeedGroup> feedGroupsArray;
  final List<ProfileProperties> profileDetailsArray;
  final bool? isLiked;
  @override
  State<FeedPostCard> createState() => _FeedPostCardState();
}

class _FeedPostCardState extends State<FeedPostCard> {
  // -------------------------------- VARIABLES -------------------------------- //
  late AudioPlayer player;
  Future<void>? _launched;
  bool _isAudioStopped = true;
  bool _isAudioPlaying = false;

  int current = 0;
  final CarouselController _controller = CarouselController();

  // -------------------------------- LIFECYCLE FUNCTION -------------------------------- //

  @override
  void initState() {
    super.initState();
    player = AudioPlayer();

    player.onPlayerCompletion.listen((final _) {
      setState(() {
        _isAudioPlaying = false;
        _isAudioStopped = true;
      });
    });
  }

  @override
  void dispose() {
    player.dispose();
    super.dispose();
  }

// -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  SizedBox build(final context) => SizedBox(
        child: postCard(
          widget.feedPost,
          widget.feedPostApi,
          context,
          widget.nameStyle,
          widget.userNameStyle,
          widget.groupTagsStyle,
        ),
      );

  // -------------------------------- UI FUNCTION -------------------------------- //

  Future<void> _launchInBrowser(final Uri url) async {
    if (!await launchUrl(url)) {
      throw Exception("Could not launch $url");
    }
  }

  String timeAgo(final String date) {
    final dt = DateTime.parse(date);
    return "${timeago.format(dt, locale: "en_short")} ago";
  }

  Column postCard(
    final FeedPost feedPost,
    final PostList feedPostApi,
    final BuildContext buildContext,
    final TextStyle? nameStyle,
    final TextStyle? userNameStyle,
    final TextStyle? groupTagsStyle,
  ) =>
      Column(
        mainAxisAlignment: MainAxisAlignment.center,
        children: [
          TextButton(
              style: TextButton.styleFrom(
                minimumSize: Size.zero,
                padding: EdgeInsets.zero,
                tapTargetSize: MaterialTapTargetSize.shrinkWrap,
              ),
              onPressed: () {
                Navigator.push(
                  context,
                  MaterialPageRoute(
                    builder: (final context) => UserProfileView(
                      headerView: HeaderView(
                        backgroundColor: Colors.indigoAccent.withOpacity(0.1),
                        leftSideIcon: IconButton(
                          onPressed: () {
                            Navigator.pop(context);
                          },
                          icon: const Icon(
                            Icons.arrow_back_outlined,
                            color: Colors.black,
                          ),
                        ),
                        header: const Text(
                          "Profile Overview",
                          style: TextStyle(color: Colors.black),
                        ),
                        headerAlignment: Alignment.centerLeft,
                      ),
                      profileImageUrl: "https://picsum.photos/201",
                      name: "Shirin Kawan",
                      nameStyle: const TextStyle(
                        fontSize: 20,
                        fontWeight: FontWeight.bold,
                      ),
                      profileDetailsArray: widget.profileDetailsArray,
                      button: Button(
                        name: "Follow",
                        onPressed: () {},
                        backgroundColor: Colors.indigoAccent,
                        textStyle: const TextStyle(color: Colors.white),
                        height: 40,
                      ),
                      profileDetailsNameStyle:
                          TextStyle(color: Colors.grey.shade600),
                      profileDetailsValueStyle:
                          const TextStyle(fontWeight: FontWeight.bold),
                      groupCardButtonColor: Colors.indigoAccent,
                      groupCardButtonStyle:
                          const TextStyle(color: Colors.white),
                      groupCardMembersStyle:
                          const TextStyle(color: Colors.grey, fontSize: 12),
                      groupCardTitleStyle: const TextStyle(
                          fontSize: 17,
                          fontWeight: FontWeight.bold,
                          color: Colors.black),
                      groupPageAboutStyle:
                          const TextStyle(fontSize: 15, color: Colors.grey),
                      groupPageMembersStyle: const TextStyle(
                          fontSize: 17,
                          fontWeight: FontWeight.bold,
                          color: Colors.black),
                      groupPageStatusStyle:
                          const TextStyle(fontSize: 17, color: Colors.grey),
                      groupPageTitleStyle: const TextStyle(
                        fontSize: 30,
                        fontWeight: FontWeight.bold,
                        color: Colors.black,
                      ),
                      avatarSize: 12,
                      postPostedTimeStyle: const TextStyle(
                        fontSize: 15,
                        color: Colors.grey,
                      ),
                      postFeedTitleStyle: const TextStyle(
                          fontSize: 15,
                          color: Colors.black,
                          fontWeight: FontWeight.bold),
                      postFeedDescriptionStyle:
                          const TextStyle(fontSize: 15, color: Colors.black),
                      postFeedAudioTitleStyle: const TextStyle(
                          fontSize: 17,
                          fontWeight: FontWeight.bold,
                          color: Colors.black),
                      postNameStyle: const TextStyle(
                          fontSize: 15,
                          fontWeight: FontWeight.bold,
                          color: Colors.black),
                      postUserNameStyle: const TextStyle(
                          fontSize: 15,
                          color: Colors.black,
                          fontWeight: FontWeight.normal),
                      postGroupTagsStyle: const TextStyle(color: Colors.indigo),
                      feedPostsArray: widget.feedPostsArray,
                      groupsList: widget.feedGroupsArray,
                    ),
                  ),
                );
              },
              child: ProfileDetails(
                name: feedPost.name,
                userName: feedPost.username,
                profileImageUrl: feedPost.profileImageUrl,
                groupTags: feedPost.groupTags,
                nameStyle: nameStyle,
                userNameStyle: userNameStyle,
                groupTagsStyle: groupTagsStyle,
                feedGroupsArray: widget.feedGroupsArray,
                feedPostsArray: widget.feedPostsArray,
                profileDetailsArray: widget.profileDetailsArray,
              )),
          const SizedBox(height: 5),
          Align(
            alignment: Alignment.centerLeft,
            child: Text(
              timeAgo(feedPostApi.createdTs),
              style: widget.postedTimeStyle ??
                  const TextStyle(
                    fontSize: 15,
                    color: Colors.grey,
                  ),
            ),
          ),
          if (feedPostApi.title != null)
            Padding(
              padding: const EdgeInsets.only(top: 5),
              child: Align(
                alignment: Alignment.centerLeft,
                child: Text(feedPostApi.title,
                    style: widget.feedTitleStyle ??
                        const TextStyle(
                            fontSize: 15,
                            color: Colors.black,
                            fontWeight: FontWeight.bold)),
              ),
            ),
          if (feedPostApi.contentMarkdown != null)
            Padding(
              padding: const EdgeInsets.only(top: 10),
              child: Align(
                alignment: Alignment.centerLeft,
                child: Text(feedPostApi.contentMarkdown!,
                    style: widget.descriptionStyle ??
                        const TextStyle(fontSize: 15, color: Colors.black)),
              ),
            ),
          if (feedPostApi.media!.imgs != null)
            Padding(
              padding: const EdgeInsets.only(top: 20),
              child: Column(
                children: [
                  CarouselSlider(
                    carouselController: _controller,
                    options: CarouselOptions(
                        enableInfiniteScroll: false,
                        enlargeCenterPage: true,
                        viewportFraction: 1,
                        onPageChanged: (final index, final reason) {
                          setState(() {
                            current = index;
                          });
                        }),
                    items: feedPostApi.media!.imgs!
                        .map((final photo) => ClipRRect(
                              borderRadius: BorderRadius.circular(5),
                              child: SizedBox.fromSize(
                                  child: Image.network(
                                photo.resizedMediaList!.first.mediaUrl,
                                fit: BoxFit.fill,
                                width: MediaQuery.of(buildContext).size.width,
                              )),
                            ))
                        .toList(),
                  ),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: feedPostApi.media!.imgs!
                        .asMap()
                        .entries
                        .map((final entry) => GestureDetector(
                              onTap: () => _controller.animateToPage(entry.key),
                              child: Container(
                                width: 12,
                                height: 12,
                                margin: const EdgeInsets.symmetric(
                                    vertical: 8, horizontal: 4),
                                decoration: BoxDecoration(
                                    shape: BoxShape.circle,
                                    color: (Theme.of(context).brightness ==
                                                Brightness.dark
                                            ? Colors.white
                                            : Colors.black)
                                        .withOpacity(
                                            current == entry.key ? 0.9 : 0.4)),
                              ),
                            ))
                        .toList(),
                  ),
                ],
              ),
            ),
          if (feedPostApi.media!.docs != null)
            Padding(
              padding: const EdgeInsets.only(top: 10),
              child: TextButton(
                onPressed: () => setState(() {
                  _launched = _launchInBrowser(
                      Uri.parse(feedPostApi.media!.docs!.first.mediaUrl!));
                }),
                child: ClipRRect(
                  borderRadius: BorderRadius.circular(5), // Image border
                  child: SizedBox.fromSize(
                      child: Image.asset(
                    const AssetImage("assets/pdf.png").assetName,
                    package: "kitcod_uikit_flutter",
                  )),
                ),
              ),
            ),

          // if (feedPost.feedVideoUrl != null)
          //   Padding(
          //     padding: const EdgeInsets.only(right: 15, left: 15),
          //     child: VideoWidget(
          //       videoPlayerController: VideoPlayerController.network(
          //         feedPost.feedVideoUrl!,
          //       ),
          //       looping: true,
          //       autoplay: false,
          //     ),
          //   ),
          // if (feedPost.feedWebsiteUrl != null)
          //   Padding(
          //     padding:
          //         const EdgeInsets.only(top: 10, right: 15, left: 15),
          //     child: Button(
          //       name: "Visit Website",
          //       onPressed: () {},
          //       backgroundColor: Colors.indigo,
          //       textStyle: const TextStyle(color: Colors.white),
          //       height: MediaQuery.of(buildContext).size.height * 0.04,
          //       width: MediaQuery.of(buildContext).size.width,
          //     ),
          //   ),
          if (feedPostApi.poll != null)
            PollsView(
                pollDetails: feedPostApi.poll,
                interactionDetails: feedPostApi.interactionSummary),

          if (feedPostApi.media!.auds != null)
            Padding(
              padding: const EdgeInsets.all(10),
              child: Align(
                alignment: Alignment.centerLeft,
                child: TextButton(
                    onPressed: () {
                      setState(() {
                        if (_isAudioPlaying && !_isAudioStopped) {
                          player.pause();
                          _isAudioPlaying = false;
                        } else if (!_isAudioPlaying && !_isAudioStopped) {
                          player.resume();
                          _isAudioPlaying = true;
                        } else {
                          player.play(
                            feedPostApi.media!.auds![0].mediaUrl!,
                          );
                          _isAudioStopped = false;
                          _isAudioPlaying = true;
                        }
                      });
                    },
                    style: ElevatedButton.styleFrom(
                        shape: const CircleBorder(),
                        padding: const EdgeInsets.all(15),
                        onPrimary: Colors.white,
                        primary: Colors.indigo),
                    child: Icon(_isAudioPlaying
                        ? Icons.pause
                        : Icons.play_arrow_sharp)),
              ),
            ),
          ShareStatsIcons(
            isLiked: widget.isLiked,
            likes: feedPostApi.interactionSummary == null
                ? 0
                : feedPostApi
                    .interactionSummary!.interactionCounts!["LIKEOPTION1"],
            comments: feedPostApi.interactionSummary == null
                ? 0
                : feedPostApi
                    .interactionSummary!.interactionCounts!["COMMENTTOT"],
            views: feedPostApi.interactionSummary == null
                ? 0
                : feedPostApi.interactionSummary!.interactionCounts!["VIEWTOT"],
          ),
          const SizedBox(height: 10),
          SizedBox(
            width: MediaQuery.of(buildContext).size.width,
            height: 3,
            child: DecoratedBox(
              decoration: BoxDecoration(color: Colors.indigo.shade50),
            ),
          ),
        ],
      );
}
