part of kitcod_uikit_flutter;

class FeedPostsList extends StatelessWidget {
  const FeedPostsList({
    required this.feedPostsArray,
    required this.feedGroupsArray,
    required this.profileDetailsArray,
    this.postedTimeStyle,
    this.feedTitleStyle,
    this.descriptionStyle,
    this.feedAudioTitleStyle,
    this.nameStyle,
    this.userNameStyle,
    this.groupTagsStyle,
    this.commentNameStyle,
    this.commentStyle,
    this.commentPostedTimeStyle,
    this.commentSubmitButtonColor,
    final Key? key,
  }) : super(key: key);

  // -------------------------------- VARIABLES -------------------------------- //
  final List<FeedPost> feedPostsArray;
  final List<FeedGroup> feedGroupsArray;
  final TextStyle? nameStyle;
  final TextStyle? groupTagsStyle;
  final TextStyle? userNameStyle;
  final TextStyle? postedTimeStyle;
  final TextStyle? feedTitleStyle;
  final TextStyle? descriptionStyle;
  final TextStyle? feedAudioTitleStyle;
  final TextStyle? commentNameStyle;
  final TextStyle? commentStyle;
  final TextStyle? commentPostedTimeStyle;
  final Color? commentSubmitButtonColor;
  final List<ProfileProperties> profileDetailsArray;

  // -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  Widget build(final BuildContext context) => SingleChildScrollView(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            FutureBuilder(
              future: KitcodApi.instance.getPostsData(),
              // ignore: avoid_types_on_closure_parameters
              builder: (final context, final AsyncSnapshot<Object> snapshot) {
                if (!snapshot.hasData) {
                  return const Center(child: Text("Loading..."));
                } else {
                  if (snapshot.hasError) {
                    return Center(child: Text("Error: ${snapshot.error}"));
                  } else {
                    final List<PostList> feedList =
                        snapshot.data! as List<PostList>;
                    return ListView.builder(
                      shrinkWrap: true,
                      physics: const NeverScrollableScrollPhysics(),
                      itemCount: feedList.length,
                      itemBuilder: (final context, final i) => ListTile(
                        title: feedPostCard(
                          feedPostsArray[0],
                          feedList[i],
                          i == 0 ? true : false,
                          context,
                        ),
                      ),
                    );
                  }
                }
              },
            ),
          ],
        ),
      );

  // -------------------------------- UI FUNCTION -------------------------------- //

  TextButton feedPostCard(
          final FeedPost? feedPost,
          final PostList feedPostApi,
          // ignore: avoid_positional_boolean_parameters
          final bool isLiked,
          final BuildContext context) =>
      TextButton(
        onPressed: () {
          Navigator.push(
              context,
              MaterialPageRoute(
                builder: (final context) => FeedPostDetails(
                  feedPost: feedPost!,
                  feedPostApi: feedPostApi,
                  headerView: HeaderView(
                    backgroundColor: Colors.white.withOpacity(0.1),
                    leftSideIcon: IconButton(
                      onPressed: () {
                        Navigator.pop(context);
                      },
                      icon: const Icon(
                        Icons.arrow_back_outlined,
                        color: Colors.black,
                      ),
                    ),
                    headerAlignment: Alignment.centerLeft,
                  ),
                  descriptionStyle: descriptionStyle,
                  feedAudioTitleStyle: feedAudioTitleStyle,
                  feedTitleStyle: feedTitleStyle,
                  postedTimeStyle: postedTimeStyle,
                  commentNameStyle: commentNameStyle,
                  commentPostedTimeStyle: commentPostedTimeStyle,
                  commentStyle: commentStyle,
                  commentSubmitButtonColor: commentSubmitButtonColor,
                  feedGroupsArray: feedGroupsArray,
                  feedPostsArray: feedPostsArray,
                  profileDetailsArray: profileDetailsArray,
                ),
              ));
        },
        child: FeedPostCard(
            feedPost: feedPost!,
            feedPostApi: feedPostApi,
            buildContext: context,
            nameStyle: nameStyle,
            userNameStyle: userNameStyle,
            groupTagsStyle: groupTagsStyle,
            descriptionStyle: descriptionStyle,
            feedAudioTitleStyle: feedAudioTitleStyle,
            feedTitleStyle: feedTitleStyle,
            postedTimeStyle: postedTimeStyle,
            feedPostsArray: feedPostsArray,
            feedGroupsArray: feedGroupsArray,
            profileDetailsArray: profileDetailsArray,
            isLiked: isLiked),
      );
}
