part of kitcod_uikit_flutter;

class GroupCards extends StatelessWidget {
  const GroupCards({
    required this.groupImageUrl,
    required this.groupTitle,
    required this.members,
    required this.membersListUrl,
    required this.groupPageStatus,
    required this.groupPageAbout,
    required this.groupPosts,
    required this.isJoined,
    required this.feedPostsArray,
    required this.feedGroupsArray,
    required this.profileDetailsArray,
    this.groupCardWidth,
    this.groupCardHeight,
    this.avatarSize,
    this.groupCardTitleStyle,
    this.groupCardMembersStyle,
    this.groupCardButtonColor,
    this.groupCardButtonStyle,
    this.groupPageTitleStyle,
    this.groupPageMembersStyle,
    this.groupPageStatusStyle,
    this.groupPageAboutStyle,
    final Key? key,
  }) : super(key: key);

  // -------------------------------- VARIABLES -------------------------------- //
  final String groupImageUrl;
  final String groupTitle;
  final String members;
  final List<String> membersListUrl;
  final String groupPageStatus;
  final String groupPageAbout;
  final List<FeedPost> groupPosts;
  final bool isJoined;
  final double? groupCardWidth;
  final double? groupCardHeight;
  final double? avatarSize;
  final TextStyle? groupCardTitleStyle;
  final TextStyle? groupCardMembersStyle;
  final TextStyle? groupCardButtonStyle;
  final Color? groupCardButtonColor;
  final TextStyle? groupPageTitleStyle;
  final TextStyle? groupPageMembersStyle;
  final TextStyle? groupPageStatusStyle;
  final TextStyle? groupPageAboutStyle;
  final List<FeedPost> feedPostsArray;
  final List<FeedGroup> feedGroupsArray;
  final List<ProfileProperties> profileDetailsArray;

// -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  TextButton build(final context) => TextButton(
      onPressed: () {
        Navigator.push(
          context,
          MaterialPageRoute(
              builder: (final context) => GroupPage(
                    groupImageUrl: groupImageUrl,
                    groupTitle: groupTitle,
                    members: members,
                    membersListUrl: membersListUrl,
                    groupPageAbout: groupPageAbout,
                    groupPosts: groupPosts,
                    groupPageStatus: groupPageStatus,
                    isJoined: isJoined,
                    groupPageAboutStyle: groupPageAboutStyle,
                    groupPageMembersStyle: groupPageMembersStyle,
                    groupPageStatusStyle: groupPageStatusStyle,
                    groupPageTitleStyle: groupCardTitleStyle,
                    feedGroupsArray: feedGroupsArray,
                    feedPostsArray: feedPostsArray,
                    profileDetailsArray: profileDetailsArray,
                  )),
        );
      },
      child: Container(
        width: groupCardWidth ?? MediaQuery.of(context).size.width * 0.42,
        height: groupCardHeight ?? MediaQuery.of(context).size.height * 0.41,
        decoration: BoxDecoration(
            border: Border.all(
              color: Colors.indigo.shade100,
            ),
            borderRadius: const BorderRadius.all(Radius.circular(20))),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            ClipRRect(
              borderRadius: const BorderRadius.only(
                  topLeft: Radius.circular(20), topRight: Radius.circular(20)),
              child: SizedBox.fromSize(
                child: Image.network(
                  groupImageUrl,
                  width: MediaQuery.of(context).size.width,
                  height: MediaQuery.of(context).size.height * 0.15,
                  fit: BoxFit.cover,
                ),
              ),
            ),
            Align(
              alignment: Alignment.centerLeft,
              child: Padding(
                padding: const EdgeInsets.only(top: 10, left: 15, right: 10),
                child: Text(groupTitle,
                    maxLines: 2,
                    overflow: TextOverflow.ellipsis,
                    style: groupCardTitleStyle ??
                        const TextStyle(
                            fontSize: 17,
                            fontWeight: FontWeight.bold,
                            color: Colors.black)),
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(left: 15),
              child: Align(
                alignment: Alignment.centerLeft,
                child: Text(members,
                    style: groupCardMembersStyle ??
                        const TextStyle(color: Colors.grey)),
              ),
            ),
            Container(
              padding: const EdgeInsets.only(left: 10),
              width: MediaQuery.of(context).size.width * 0.8,
              child: Wrap(
                children: [
                  Padding(
                    padding: const EdgeInsets.all(3),
                    child: CircleAvatar(
                      radius: avatarSize ?? 15,
                      backgroundImage: NetworkImage(membersListUrl[0]),
                      backgroundColor: Colors.transparent,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(3),
                    child: CircleAvatar(
                      radius: avatarSize ?? 15,
                      backgroundImage: NetworkImage(membersListUrl[1]),
                      backgroundColor: Colors.transparent,
                    ),
                  ),
                  Padding(
                    padding: const EdgeInsets.all(3),
                    child: CircleAvatar(
                      radius: avatarSize ?? 15,
                      backgroundImage: NetworkImage(membersListUrl[2]),
                      backgroundColor: Colors.transparent,
                    ),
                  ),
                ],
              ),
            ),
            Padding(
              padding: const EdgeInsets.only(bottom: 10, left: 10, right: 10),
              child: Button(
                  name: "Join",
                  onPressed: () {},
                  backgroundColor: groupCardButtonColor ?? Colors.indigoAccent,
                  textStyle: groupCardButtonStyle ??
                      const TextStyle(color: Colors.white),
                  width: MediaQuery.of(context).size.width,
                  height: MediaQuery.of(context).size.height * 0.05),
            ),
          ],
        ),
      ));
}
