part of kitcod_uikit_flutter;

class GroupsList extends StatelessWidget {
  const GroupsList({
    required this.feedGroupsArray,
    required this.profileDetailsArray,
    required this.feedPostsArray,
    final Key? key,
  }) : super(key: key);

  // -------------------------------- VARIABLES -------------------------------- //
  final List<FeedGroup> feedGroupsArray;
  final List<FeedPost> feedPostsArray;
  final List<ProfileProperties> profileDetailsArray;

  // -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  Widget build(final BuildContext context) => SingleChildScrollView(
        scrollDirection: Axis.horizontal,
        physics: const ScrollPhysics(),
        child: Padding(
          padding: const EdgeInsets.symmetric(horizontal: 10),
          child: Row(
            children: [
              FutureBuilder(
                  future: KitcodApi.instance.getGroupsData(),
                  // ignore: avoid_types_on_closure_parameters
                  builder: (final context, final snapshot) {
                    if (!snapshot.hasData) {
                      return const Center(child: Text("Loading..."));
                    } else {
                      if (snapshot.hasError) {
                        return Center(child: Text("Error: ${snapshot.error}"));
                      } else {
                        final List<CommunitiesList> communitiesList =
                            snapshot.data! as List<CommunitiesList>;
                        return SizedBox(
                          height: 110,
                          width: MediaQuery.of(context).size.width * 0.95,
                          child: ListView.builder(
                            itemCount: communitiesList.length,
                            itemExtent: 75,
                            scrollDirection: Axis.horizontal,
                            shrinkWrap: true,
                            itemBuilder: (final context, final i) {
                              if (i == 0) {
                                return addStoryButton(context);
                              }
                              return groupStory(communitiesList[i], context);
                            },
                          ),
                        );
                      }
                    }
                  })
            ],
          ),
        ),
      );

  // -------------------------------- UI FUNCTION -------------------------------- //
  TextButton groupStory(
          final CommunitiesList community, final BuildContext context) =>
      TextButton(
          style: TextButton.styleFrom(
            minimumSize: Size.zero,
            padding: const EdgeInsets.all(3),
            tapTargetSize: MaterialTapTargetSize.shrinkWrap,
          ),
          onPressed: () {
            Navigator.push(
              context,
              MaterialPageRoute(
                  builder: (final context) => GroupPage(
                        groupImageUrl: community.media.proImg == null
                            ? "https://picsum.photos/201"
                            : community
                                .media.proImg!.resizedMediaList.first.mediaUrl,
                        groupTitle: community.name,
                        members: community.rangeMembersCount == null
                            ? ""
                            : community.rangeMembersCount.toString(),
                        membersListUrl: feedGroupsArray[0].membersImageUrls,
                        groupPageAbout: community.description,
                        groupPosts: feedGroupsArray[0].groupPosts!,
                        groupPageStatus: "Open group",
                        isJoined: false,
                        feedGroupsArray: feedGroupsArray,
                        feedPostsArray: feedPostsArray,
                        profileDetailsArray: profileDetailsArray,
                      )),
            );
          },
          child: Column(
            children: [
              Expanded(
                child: Container(
                  height: 80,
                  width: 80,
                  decoration: BoxDecoration(
                    boxShadow: const [
                      BoxShadow(
                        color: Colors.white54,
                        blurRadius: 5,
                        offset: Offset(0, 10),
                        spreadRadius: 0.5,
                      ),
                    ],
                    borderRadius: BorderRadius.circular(12),
                  ),
                  child: Card(
                    elevation: 4,
                    shape: RoundedRectangleBorder(
                        borderRadius: BorderRadius.circular(13),
                        side: const BorderSide(width: 2, color: Colors.blue)),
                    child: ClipRRect(
                      borderRadius: BorderRadius.circular(12), // Image border
                      child: SizedBox.fromSize(
                        child: Image.network(
                          community.media.proImg == null
                              ? "https://picsum.photos/201"
                              : community.media.proImg!.resizedMediaList.first
                                  .mediaUrl,
                        ),
                      ),
                    ),
                  ),
                ),
              ),
              const SizedBox(height: 5),
              SizedBox(
                width: 60,
                child: Text(
                  community.name,
                  maxLines: 2,
                  textAlign: TextAlign.center,
                  overflow: TextOverflow.fade,
                  style: const TextStyle(fontSize: 12),
                ),
              ),
            ],
          ));

  TextButton addStoryButton(final BuildContext context) => TextButton(
        style: TextButton.styleFrom(
          minimumSize: Size.zero,
          padding: const EdgeInsets.all(3),
          tapTargetSize: MaterialTapTargetSize.shrinkWrap,
        ),
        onPressed: () {
          Navigator.push(
            context,
            MaterialPageRoute(
              builder: (final context) => CreateGroupCommunity(
                headerView: HeaderView(
                  backgroundColor: Colors.white.withOpacity(0.1),
                  leftSideIcon: IconButton(
                    onPressed: () {
                      Navigator.pop(context);
                    },
                    icon: const Icon(
                      Icons.arrow_back_outlined,
                      color: Colors.black,
                    ),
                  ),
                  header: const Text(
                    "Create New Group",
                    style: TextStyle(color: Colors.black),
                  ),
                  headerAlignment: Alignment.centerLeft,
                ),
                heading: "Community Access",
                description: "Choose who can join the community",
              ),
            ),
          );
        },
        child: Column(
          // direction: Axis.vertical,
          children: [
            Expanded(
              child: Container(
                height: 70,
                width: 80,
                decoration: BoxDecoration(
                  boxShadow: const [
                    BoxShadow(
                      color: Colors.white54,
                      blurRadius: 5,
                      offset: Offset(0, 10),
                      spreadRadius: 0.5,
                    ),
                  ],
                  borderRadius: BorderRadius.circular(12),
                ),
                child: Card(
                  color: Colors.grey.shade200,
                  shape: RoundedRectangleBorder(
                    borderRadius: BorderRadius.circular(12),
                  ),
                  elevation: 4,
                  child: Center(
                    child: Icon(
                      Icons.add,
                      size: 50,
                      color: Colors.grey.shade400,
                    ),
                  ),
                ),
              ),
            ),
            const SizedBox(height: 5),
            const SizedBox(
              width: 70,
              child: Text(
                "Create New Group",
                maxLines: 2,
                textAlign: TextAlign.center,
                overflow: TextOverflow.fade,
                style: TextStyle(fontSize: 12),
              ),
            ),
          ],
        ),
      );
}
