// ignore_for_file: tighten_type_of_initializing_formals, unnecessary_null_comparison, prefer_asserts_with_message, prefer_int_literals, avoid_dynamic_calls, always_put_control_body_on_new_line, avoid_redundant_argument_values, noop_primitive_operations, only_throw_errors, unnecessary_this, avoid_classes_with_only_static_members, always_declare_return_types, prefer_final_locals, use_key_in_widget_constructors, sort_constructors_first, prefer_const_constructors_in_immutables, prefer_if_null_operators
part of kitcod_uikit_flutter;

typedef PollCallBack = void Function(int choice);

typedef PollTotal = void Function(int total);

late int userPollChoice;

class Polls extends StatefulWidget {
  /// takes the question on the poll
  final Text? question;

  ///determines what type of view user should see
  ///if its creator, or view requiring you to vote or view showing your vote
  final PollsType? viewType;

  ///takes in vote data which should be a Map
  /// with  polls widget determines what type of view the user should see
  final Map? voteData;

  final String? currentUser;

  final String? creatorID;

  /// takes in poll options array
  final List children;

  /// call back returns user choice after voting
  final PollCallBack? onVote;

  /// is takes in current user choice
  final int? userChoice;

  /// determines if the creator of the poll can vote or not
  final bool allowCreatorVote;

  /// returns total votes casted
  final PollTotal? getTotal;

  /// returns lowest votes casted
  final PollTotal? getlowest;

  @protected
  final double? lowest;

  /// style
  final TextStyle? pollStyle;
  final TextStyle? leadingPollStyle;
  final TextStyle? lowestPollStyle;
  final TextStyle? onVotePollStyle;

  ///colors setting for polls widget
  final Color outlineColor;
  final Color backgroundColor;
  final Color? onVoteBackgroundColor;
  final Color? iconColor;
  final Color? lowestBackgroundColor;

  /// Polls contruct by default get view for voting
  Polls({
    required this.children,
    required this.voteData,
    required this.currentUser,
    required this.creatorID,
    this.question,
    this.userChoice,
    this.allowCreatorVote = false,
    this.onVote,
    this.outlineColor = Colors.blue,
    this.backgroundColor = Colors.white,
    this.onVoteBackgroundColor = Colors.white,
    this.onVotePollStyle,
    this.leadingPollStyle,
    this.pollStyle,
    this.iconColor = Colors.black,
    this.lowestBackgroundColor = Colors.blueGrey,
    this.lowestPollStyle,
  })  : lowest = null,
        getlowest = null,
        getTotal = null,
        viewType = null,
        assert(onVote != null),
        assert(children != null),
        assert(voteData != null),
        assert(currentUser != null),
        assert(creatorID != null);

  /// Polls.option is used to set polls options
  static List options(
      {required final String title, required final double value}) {
    if (title != null && value != null) {
      return [title, value];
    } else {
      throw "Poll Option(title or Value is equal to )";
    }
  }

  /// creates view for see polls result
  Polls.viewPolls(
      {required this.children,
      this.question,
      this.userChoice,
      this.leadingPollStyle,
      this.pollStyle,
      this.backgroundColor = Colors.white,
      this.lowestBackgroundColor = Colors.blueAccent,
      this.onVoteBackgroundColor = Colors.white,
      this.iconColor = Colors.black,
      this.lowestPollStyle,
      this.onVotePollStyle})
      : allowCreatorVote = false,
        getTotal = null,
        lowest = null,
        voteData = null,
        currentUser = null,
        creatorID = null,
        getlowest = null,
        outlineColor = Colors.transparent,
        viewType = PollsType.readOnly,
        onVote = null,
        assert(children != null),
        assert(question != null);

  /// This creates view for the creator of the polls
  Polls.creator(
      {required this.children,
      this.question,
      this.leadingPollStyle,
      this.pollStyle,
      this.backgroundColor = Colors.white,
      this.lowestBackgroundColor = Colors.blueAccent,
      this.onVoteBackgroundColor = Colors.white,
      this.allowCreatorVote = false,
      this.lowestPollStyle,
      this.onVotePollStyle})
      : viewType = PollsType.creator,
        onVote = null,
        userChoice = null,
        lowest = null,
        getlowest = null,
        voteData = null,
        currentUser = null,
        creatorID = null,
        getTotal = null,
        iconColor = null,
        outlineColor = Colors.transparent,
        assert(children != null),
        assert(question != null);

  /// this creates view for users to cast votes
  Polls.castVote({
    required this.children,
    required this.onVote,
    this.question,
    this.allowCreatorVote = false,
    this.outlineColor = Colors.blue,
    this.backgroundColor = Colors.white,
    this.pollStyle,
    this.onVotePollStyle,
    this.lowestPollStyle,
  })  : viewType = PollsType.voter,
        userChoice = null,
        lowest = null,
        getlowest = null,
        getTotal = null,
        iconColor = null,
        voteData = null,
        currentUser = null,
        creatorID = null,
        lowestBackgroundColor = null,
        leadingPollStyle = null,
        onVoteBackgroundColor = null,
        assert(onVote != null),
        assert(children != null);

  @override
  _PollsState createState() => _PollsState();
}

class _PollsState extends State<Polls> {
  /// c1 stands for choice 1
  @protected
  late String c1;

  /// c2 stands for choice 2
  @protected
  late String c2;

  /// c3 stands for choice 3
  @protected
  String? c3;

  /// c4 stands for choice 4
  @protected
  String? c4;

  /// c3 stands for choice 5
  @protected
  String? c5;

  /// c4 stands for choice 6
  @protected
  String? c6;

  /// c3 stands for choice 7
  @protected
  String? c7;

  /// c4 stands for choice 8
  @protected
  String? c8;

  /// v1 stands for value 1
  @protected
  late double v1;

  /// v2 stands for value 2
  @protected
  late double v2;

  @protected
  double? v3;

  @protected
  double? v4;

  @protected
  double? v5;

  @protected
  double? v6;

  @protected
  double? v7;

  @protected
  double? v8;

  /// user choices
  String choice1Title = "";

  String choice2Title = "";

  String choice3Title = "";

  String choice4Title = "";

  String choice5Title = "";

  String choice6Title = "";

  String choice7Title = "";

  String choice8Title = "";

  double choice1Value = 0.0;

  double choice2Value = 0.0;

  double choice3Value = 0.0;

  double choice4Value = 0.0;

  double choice5Value = 0.0;

  double choice6Value = 0.0;

  double choice7Value = 0.0;

  double choice8Value = 0.0;

  /// style
  TextStyle? pollStyle;
  TextStyle? leadingPollStyle;
  TextStyle? onVotePollStyle;
  TextStyle? lowestPollStyle;

  ///colors setting for polls widget
  Color? outlineColor;
  Color? backgroundColor;
  Color? onVoteBackgroundColor;
  Color? iconColor;
  Color? lowestBackgroundColor;

  late double lowest;

  @override
  void initState() {
    super.initState();

    /// if polls style is null, it sets default pollstyle and leading pollstyle
    pollStyle = widget.pollStyle == null
        ? const TextStyle(color: Colors.black, fontWeight: FontWeight.w300)
        : pollStyle;
    leadingPollStyle = widget.leadingPollStyle == null
        ? const TextStyle(color: Colors.black, fontWeight: FontWeight.w800)
        : this.leadingPollStyle;
    lowestPollStyle = widget.lowestPollStyle == null
        ? const TextStyle(color: Colors.red, fontWeight: FontWeight.w300)
        : lowestPollStyle;
    onVotePollStyle = widget.lowestPollStyle == null
        ? const TextStyle(color: Colors.blue, fontWeight: FontWeight.w300)
        : onVotePollStyle;

    /// choice values are set from children
    this.choice1Value = widget.children[0][1] as double;
    this.choice1Title = widget.children[0][0] as String;
    this.v1 = widget.children[0][1] as double;
    this.c1 = widget.children[0][0] as String;

    this.choice2Value = widget.children[1][1] as double;
    this.choice2Title = widget.children[1][0] as String;
    this.v2 = widget.children[1][1] as double;
    this.c2 = widget.children[1][0] as String;

    if (widget.children.length > 2) {
      this.choice3Value = widget.children[2][1] as double;
      this.choice3Title = widget.children[2][0] as String;
      this.v3 = widget.children[2][1] as double;
      this.c3 = widget.children[2][0] as String;
    }

    if (widget.children.length > 3) {
      this.choice4Value = widget.children[3][1] as double;
      this.choice4Title = widget.children[3][0] as String;
      this.v4 = widget.children[3][1] as double;
      this.c4 = widget.children[3][0] as String;
    }

    if (widget.children.length > 4) {
      this.choice5Value = widget.children[4][1] as double;
      this.choice5Title = widget.children[4][0] as String;
      this.v5 = widget.children[4][1] as double;
      this.c5 = widget.children[4][0] as String;
    }

    if (widget.children.length > 5) {
      this.choice6Value = widget.children[5][1] as double;
      this.choice6Title = widget.children[5][0] as String;
      this.v6 = widget.children[5][1] as double;
      this.c6 = widget.children[5][0] as String;
    }

    if (widget.children.length > 6) {
      this.choice7Value = widget.children[6][1] as double;
      this.choice7Title = widget.children[6][0] as String;
      this.v7 = widget.children[6][1] as double;
      this.c7 = widget.children[6][0] as String;
    }

    if (widget.children.length > 7) {
      this.choice8Value = widget.children[7][1] as double;
      this.choice8Title = widget.children[7][0] as String;
      this.v8 = widget.children[7][1] as double;
      this.c8 = widget.children[7][0] as String;
    }
  }

  @override
  Widget build(final BuildContext context) {
    if (widget.viewType == null) {
      final viewType =
          (widget.voteData?.containsKey(widget.currentUser) ?? false)
              ? PollsType.readOnly
              : widget.currentUser == widget.creatorID
                  ? PollsType.creator
                  : PollsType.voter;
      if (viewType == PollsType.voter) {
        //user can cast vote with this widget
        return voterWidget(context);
      }
      if (viewType == PollsType.creator) {
        //mean this is the creator of the polls and cannot vote
        if (widget.allowCreatorVote) {
          return voterWidget(context);
        }
        return pollCreator(context);
      }

      if (viewType == PollsType.readOnly) {
        //user can view his votes with this widget
        return voteCasted(context);
      }
    } else {
      if (widget.viewType == PollsType.voter) {
        //user can cast vote with this widget
        return voterWidget(context);
      }
      if (widget.viewType == PollsType.creator) {
        //mean this is the creator of the polls and cannot vote
        if (widget.allowCreatorVote) {
          return voterWidget(context);
        }
        return pollCreator(context);
      }

      if (widget.viewType == PollsType.readOnly) {
        //user can view his votes with this widget
        return voteCasted(context);
      }
    }
    return Container();
  }

  /// voterWidget creates view for users to cast their votes

  Widget voterWidget(final context) => Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        children: <Widget>[
          const SizedBox(
            height: 12,
          ),
          Container(
            width: double.infinity,
            padding: const EdgeInsets.only(bottom: 20),
            child: Container(
              margin: const EdgeInsets.all(1),
              width: MediaQuery.of(context as BuildContext).size.width,
              padding: const EdgeInsets.all(1),
              height: 40,
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(20),
                color: widget.backgroundColor,
              ),
              child: OutlinedButton(
                onPressed: () {
                  setState(() {
                    userPollChoice = 1;
                  });
                  widget.onVote!(userPollChoice);
                },
                style: OutlinedButton.styleFrom(
                    shape: const RoundedRectangleBorder(
                      borderRadius: BorderRadius.all(Radius.circular(20)),
                    ),
                    side: BorderSide(color: widget.outlineColor)),
                child: Padding(
                  padding: const EdgeInsets.only(left: 10),
                  child: Align(
                      alignment: Alignment.centerLeft,
                      child: Text(this.c1, style: widget.pollStyle)),
                ),
              ),
            ),
          ),
          Container(
            width: double.infinity,
            padding: const EdgeInsets.only(bottom: 20),
            child: Container(
              margin: const EdgeInsets.all(1),
              padding: const EdgeInsets.all(1),
              height: 40,
              width: MediaQuery.of(context).size.width,
              decoration: BoxDecoration(
                borderRadius: BorderRadius.circular(20),
                color: widget.backgroundColor,
              ),
              child: OutlinedButton(
                onPressed: () {
                  setState(() {
                    userPollChoice = 2;
                  });
                  widget.onVote!(userPollChoice);
                },
                style: OutlinedButton.styleFrom(
                    shape: const RoundedRectangleBorder(
                      borderRadius: BorderRadius.all(Radius.circular(20)),
                    ),
                    side: BorderSide(color: widget.outlineColor)),
                child: Padding(
                  padding: const EdgeInsets.only(left: 10),
                  child: Align(
                      alignment: Alignment.centerLeft,
                      child: Text(this.c2, style: widget.pollStyle)),
                ),
              ),
            ),
          ),
          if (this.c3 != null)
            Container(
              width: double.infinity,
              padding: const EdgeInsets.only(bottom: 20),
              child: Container(
                margin: const EdgeInsets.all(1),
                padding: const EdgeInsets.all(1),
                height: 40,
                width: MediaQuery.of(context).size.width,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(20),
                  color: widget.backgroundColor,
                ),
                child: OutlinedButton(
                  onPressed: () {
                    setState(() {
                      userPollChoice = 3;
                    });
                    widget.onVote!(userPollChoice);
                  },
                  style: OutlinedButton.styleFrom(
                      shape: const RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(20)),
                      ),
                      side: BorderSide(color: widget.outlineColor)),
                  child: Padding(
                    padding: const EdgeInsets.only(left: 10),
                    child: Align(
                        alignment: Alignment.centerLeft,
                        child: Text(this.c3 ?? "", style: widget.pollStyle)),
                  ),
                ),
              ),
            )
          else
            const Offstage(),
          if (c4 != null)
            Container(
              width: double.infinity,
              padding: const EdgeInsets.only(bottom: 20),
              child: Container(
                margin: const EdgeInsets.all(1),
                padding: const EdgeInsets.all(1),
                height: 40,
                width: MediaQuery.of(context).size.width,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(20),
                  color: widget.backgroundColor,
                ),
                child: OutlinedButton(
                  onPressed: () {
                    setState(() {
                      userPollChoice = 4;
                    });
                    widget.onVote!(userPollChoice);
                  },
                  style: OutlinedButton.styleFrom(
                      shape: const RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(20)),
                      ),
                      side: BorderSide(color: widget.outlineColor)),
                  child: Padding(
                    padding: const EdgeInsets.only(left: 10),
                    child: Align(
                        alignment: Alignment.centerLeft,
                        child: Text(this.c3 ?? "", style: widget.pollStyle)),
                  ),
                ),
              ),
            )
          else
            const Offstage(),
          if (c5 != null)
            Container(
              width: double.infinity,
              padding: const EdgeInsets.only(bottom: 20),
              child: Container(
                margin: const EdgeInsets.all(1),
                padding: const EdgeInsets.all(1),
                height: 40,
                width: MediaQuery.of(context).size.width,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(20),
                  color: widget.backgroundColor,
                ),
                child: OutlinedButton(
                  onPressed: () {
                    setState(() {
                      userPollChoice = 5;
                    });
                    widget.onVote!(userPollChoice);
                  },
                  style: OutlinedButton.styleFrom(
                      shape: const RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(20)),
                      ),
                      side: BorderSide(color: widget.outlineColor)),
                  child: Padding(
                    padding: const EdgeInsets.only(left: 10),
                    child: Align(
                        alignment: Alignment.centerLeft,
                        child: Text(this.c3 ?? "", style: widget.pollStyle)),
                  ),
                ),
              ),
            )
          else
            const Offstage(),
          if (this.c6 != null)
            Container(
              width: double.infinity,
              padding: const EdgeInsets.only(bottom: 20),
              child: Container(
                margin: const EdgeInsets.all(1),
                padding: const EdgeInsets.all(1),
                height: 40,
                width: MediaQuery.of(context).size.width,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(20),
                  color: widget.backgroundColor,
                ),
                child: OutlinedButton(
                  onPressed: () {
                    setState(() {
                      userPollChoice = 6;
                    });
                    widget.onVote!(userPollChoice);
                  },
                  style: OutlinedButton.styleFrom(
                      shape: const RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(20)),
                      ),
                      side: BorderSide(color: widget.outlineColor)),
                  child: Padding(
                    padding: const EdgeInsets.only(left: 10),
                    child: Align(
                        alignment: Alignment.centerLeft,
                        child: Text(this.c3 ?? "", style: widget.pollStyle)),
                  ),
                ),
              ),
            )
          else
            const Offstage(),
          if (c7 != null)
            Container(
              width: double.infinity,
              padding: const EdgeInsets.only(bottom: 20),
              child: Container(
                margin: const EdgeInsets.all(1),
                padding: const EdgeInsets.all(1),
                height: 40,
                width: MediaQuery.of(context).size.width,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(20),
                  color: widget.backgroundColor,
                ),
                child: OutlinedButton(
                  onPressed: () {
                    setState(() {
                      userPollChoice = 7;
                    });
                    widget.onVote!(userPollChoice);
                  },
                  style: OutlinedButton.styleFrom(
                      shape: const RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(20)),
                      ),
                      side: BorderSide(color: widget.outlineColor)),
                  child: Padding(
                    padding: const EdgeInsets.only(left: 10),
                    child: Align(
                        alignment: Alignment.centerLeft,
                        child: Text(this.c3 ?? "", style: widget.pollStyle)),
                  ),
                ),
              ),
            )
          else
            const Offstage(),
          if (c8 != null)
            Container(
              width: double.infinity,
              padding: const EdgeInsets.only(bottom: 20),
              child: Container(
                margin: const EdgeInsets.all(1),
                padding: const EdgeInsets.all(1),
                height: 40,
                width: MediaQuery.of(context).size.width,
                decoration: BoxDecoration(
                  borderRadius: BorderRadius.circular(20),
                  color: widget.backgroundColor,
                ),
                child: OutlinedButton(
                  onPressed: () {
                    setState(() {
                      userPollChoice = 8;
                    });
                    widget.onVote!(userPollChoice);
                  },
                  style: OutlinedButton.styleFrom(
                      shape: const RoundedRectangleBorder(
                        borderRadius: BorderRadius.all(Radius.circular(20)),
                      ),
                      side: BorderSide(color: widget.outlineColor)),
                  child: Padding(
                    padding: const EdgeInsets.only(left: 10),
                    child: Align(
                        alignment: Alignment.centerLeft,
                        child: Text(this.c3 ?? "", style: widget.pollStyle)),
                  ),
                ),
              ),
            )
          else
            const Offstage(),
        ],
      );

  /// pollCreator creates view for the creator of the polls,
  /// to see poll activities
  Widget pollCreator(final context) {
    // ignore: prefer_final_locals
    var sortedKeys = [
      this.v1,
      this.v2,
      this.v3,
      this.v4,
      this.v5,
      this.v6,
      this.v7,
      this.v8
    ];

    double current = 10000000000000000;

    for (var i = 0; i < sortedKeys.length; i++) {
      if (sortedKeys[i] != null) {
        final double s = double.parse(sortedKeys[i].toString());

        if ((sortedKeys[i] ?? 0) <= current) {
          current = s;
        }
      }
    }

    lowest = current;

    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        const SizedBox(
          height: 12,
        ),
        Container(
          padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
          margin: const EdgeInsets.only(bottom: 20),
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey.shade300),
            borderRadius: BorderRadius.circular(22),
          ),
          width: double.infinity,
          child: LinearPercentIndicator(
              animation: true,
              lineHeight: 38.0,
              animationDuration: 600,
              percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 1)[0]
                  as double,
              center: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: <Widget>[
                      Text(c1,
                          style: lowest == v1
                              ? widget.leadingPollStyle
                              : widget.pollStyle),
                      const SizedBox(
                        width: 10,
                      ),
                    ],
                  ),
                  Text(
                      "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 1)}%",
                      style: lowest == v1
                          ? widget.leadingPollStyle
                          : widget.pollStyle)
                ],
              ),
              linearStrokeCap: LinearStrokeCap.roundAll,
              progressColor: lowest == v1
                  ? widget.lowestBackgroundColor
                  : widget.onVoteBackgroundColor),
        ),
        Container(
          padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
          margin: const EdgeInsets.only(bottom: 20),
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey.shade300),
            borderRadius: BorderRadius.circular(22),
          ),
          width: double.infinity,
          child: LinearPercentIndicator(
//              width: MediaQuery.of(context).size.width,

              animation: true,
              lineHeight: 38.0,
              animationDuration: 600,
              percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 3)[0]
                  as double,
              center: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: <Widget>[
                      Text(c2,
                          style: widget.lowest == v2
                              ? widget.leadingPollStyle
                              : widget.pollStyle),
                      const SizedBox(
                        width: 10,
                      ),
                    ],
                  ),
                  Text(
                      "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 2)}%",
                      style: lowest == v2
                          ? widget.leadingPollStyle
                          : widget.pollStyle)
                ],
              ),
              linearStrokeCap: LinearStrokeCap.roundAll,
              progressColor: lowest == v2
                  ? widget.lowestBackgroundColor
                  : widget.onVoteBackgroundColor),
        ),
        if (c3 != null)
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
//              width: MediaQuery.of(context).size.width,

                animation: true,
                lineHeight: 38.0,
                animationDuration: 600,
                percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 3)[0]
                    as double,
                center: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    Row(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: <Widget>[
                        Text(this.c3 ?? "",
                            style: this.lowest == this.v3
                                ? widget.leadingPollStyle
                                : widget.pollStyle),
                        const SizedBox(
                          width: 10,
                        ),
                      ],
                    ),
                    Text(
                        "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 3)}%",
                        style: lowest == v3
                            ? widget.leadingPollStyle
                            : widget.pollStyle)
                  ],
                ),
                linearStrokeCap: LinearStrokeCap.roundAll,
                progressColor: lowest == v3
                    ? widget.lowestBackgroundColor
                    : widget.onVoteBackgroundColor),
          )
        else
          const Offstage(),
        if (c4 != null)
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
                animation: true,
                lineHeight: 38.0,
                animationDuration: 500,
                percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 4)[0]
                    as double,
                center: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    Row(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: <Widget>[
                        Text(this.c4.toString(),
                            style: widget.lowest == this.v4
                                ? widget.leadingPollStyle
                                : widget.pollStyle),
                        const SizedBox(
                          width: 10,
                        ),
                      ],
                    ),
                    Text(
                        "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 4)}%",
                        style: this.lowest == this.v4
                            ? widget.leadingPollStyle
                            : widget.pollStyle)
                  ],
                ),
                linearStrokeCap: LinearStrokeCap.roundAll,
                progressColor: lowest == v4
                    ? widget.lowestBackgroundColor
                    : widget.onVoteBackgroundColor),
          )
        else
          const Offstage(),
        if (c5 != null)
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
                animation: true,
                lineHeight: 38.0,
                animationDuration: 500,
                percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 5)[0]
                    as double,
                center: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    Row(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: <Widget>[
                        Text(c5.toString(),
                            style: widget.lowest == v5
                                ? widget.leadingPollStyle
                                : widget.pollStyle),
                        const SizedBox(
                          width: 10,
                        ),
                      ],
                    ),
                    Text(
                        "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 5)}%",
                        style: this.lowest == this.v5
                            ? widget.leadingPollStyle
                            : widget.pollStyle)
                  ],
                ),
                linearStrokeCap: LinearStrokeCap.roundAll,
                progressColor: this.lowest == this.v5
                    ? widget.lowestBackgroundColor
                    : widget.onVoteBackgroundColor),
          )
        else
          const Offstage(),
        if (this.c6 != null)
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
                animation: true,
                lineHeight: 38.0,
                animationDuration: 600,
                percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 6)[0]
                    as double,
                center: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    Row(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: <Widget>[
                        Text(c6.toString(),
                            style: widget.lowest == v6
                                ? widget.leadingPollStyle
                                : widget.pollStyle),
                        const SizedBox(
                          width: 10,
                        ),
                      ],
                    ),
                    Text(
                        "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 6)}%",
                        style: lowest == v6
                            ? widget.leadingPollStyle
                            : widget.pollStyle)
                  ],
                ),
                linearStrokeCap: LinearStrokeCap.roundAll,
                progressColor: this.lowest == this.v6
                    ? widget.lowestBackgroundColor
                    : widget.onVoteBackgroundColor),
          )
        else
          const Offstage(),
        if (this.c7 != null)
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
                animation: true,
                lineHeight: 38.0,
                animationDuration: 600,
                percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 7)[0]
                    as double,
                center: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    Row(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: <Widget>[
                        Text(c7.toString(),
                            style: widget.lowest == v7
                                ? widget.leadingPollStyle
                                : widget.pollStyle),
                        const SizedBox(
                          width: 10,
                        ),
                      ],
                    ),
                    Text(
                        "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 7)}%",
                        style: lowest == v7
                            ? widget.leadingPollStyle
                            : widget.pollStyle)
                  ],
                ),
                linearStrokeCap: LinearStrokeCap.roundAll,
                progressColor: lowest == v7
                    ? widget.lowestBackgroundColor
                    : widget.onVoteBackgroundColor),
          )
        else
          const Offstage(),
        if (c8 != null)
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
                animation: true,
                lineHeight: 38.0,
                animationDuration: 500,
                percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 8)[0]
                    as double,
                center: Row(
                  mainAxisAlignment: MainAxisAlignment.spaceBetween,
                  children: <Widget>[
                    Row(
                      mainAxisAlignment: MainAxisAlignment.start,
                      children: <Widget>[
                        Text(c8.toString(),
                            style: widget.lowest == v8
                                ? widget.leadingPollStyle
                                : widget.pollStyle),
                        const SizedBox(
                          width: 10,
                        ),
                      ],
                    ),
                    Text(
                        "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 8)}%",
                        style: this.lowest == this.v8
                            ? widget.leadingPollStyle
                            : widget.pollStyle)
                  ],
                ),
                linearStrokeCap: LinearStrokeCap.roundAll,
                progressColor: lowest == v8
                    ? widget.lowestBackgroundColor
                    : widget.onVoteBackgroundColor),
          )
        else
          const Offstage(),
      ],
    );
  }

  /// voteCasted created view for user to see votes they casted including other peoples vote
  Widget voteCasted(final context) {
    /// Fix by AksharPrasanna
    v1 = widget.children[0][1] as double;
    v2 = widget.children[1][1] as double;
    if (c3 != null) v3 = widget.children[2][1] as double;
    if (c4 != null) v4 = widget.children[3][1] as double;
    if (c5 != null) v5 = widget.children[4][1] as double;
    if (c6 != null) v6 = widget.children[5][1] as double;
    if (c7 != null) v7 = widget.children[6][1] as double;
    if (c8 != null) v8 = widget.children[7][1] as double;

    var sortedKeys = [v1, v2, v3, v4, v5, v6, v7, v8];
    double current = 100000000000000;
    for (var i = 0; i < sortedKeys.length; i++) {
      if (sortedKeys[i] != null) {
        final s = double.parse(sortedKeys[i].toString());
        if ((sortedKeys[i] ?? 0) <= current) {
          current = s;
        }
      }
    }
    lowest = current;
    return Column(
      crossAxisAlignment: CrossAxisAlignment.start,
      children: <Widget>[
        const SizedBox(
          height: 12,
        ),
        Container(
          padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
          margin: const EdgeInsets.only(bottom: 20),
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey.shade300),
            borderRadius: BorderRadius.circular(22),
          ),
          width: double.infinity,
          child: LinearPercentIndicator(
            animation: true,
            lineHeight: 38,
            animationDuration: 600,
            percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 1)[0]
                as double,
            center: Row(
              mainAxisAlignment: MainAxisAlignment.start,
              children: <Widget>[
                Text(
                  "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 1)}%  ${c1.toString()}",
                  style: widget.userChoice == 1
                      ? const TextStyle(
                          color: Colors.indigo, fontWeight: FontWeight.bold)
                      : (lowest == v1
                          ? widget.lowestPollStyle
                          : widget.onVotePollStyle),
                ),
              ],
            ),
            linearStrokeCap: LinearStrokeCap.roundAll,
            progressColor: lowest == v1
                ? widget.lowestBackgroundColor
                : widget.onVoteBackgroundColor,
            backgroundColor: Colors.white,
          ),
        ),
        Container(
          padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
          margin: const EdgeInsets.only(bottom: 20),
          decoration: BoxDecoration(
            border: Border.all(color: Colors.grey.shade300),
            borderRadius: BorderRadius.circular(22),
          ),
          width: double.infinity,
          child: LinearPercentIndicator(
//              width: MediaQuery.of(context).size.width,
            animation: true,
            lineHeight: 38.0,
            animationDuration: 500,
            percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 2)[0]
                as double,
            center: Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: <Widget>[
                Row(
                  mainAxisAlignment: MainAxisAlignment.start,
                  children: <Widget>[
                    Text(
                      "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 2)}%  ${c2.toString()}",
                      style: widget.userChoice == 2
                          ? const TextStyle(
                              color: Colors.indigo, fontWeight: FontWeight.bold)
                          : (lowest == v2
                              ? widget.lowestPollStyle
                              : widget.onVotePollStyle),
                    ),
                  ],
                ),
              ],
            ),
            linearStrokeCap: LinearStrokeCap.roundAll,
            progressColor: lowest == v2
                ? widget.lowestBackgroundColor
                : widget.onVoteBackgroundColor,
            backgroundColor: Colors.white,
          ),
        ),
        if (c3 == null)
          const Offstage()
        else
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
//              width: MediaQuery.of(context).size.width,
              animation: true,
              lineHeight: 38.0,
              animationDuration: 500,
              percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 3)[0]
                  as double,
              center: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: <Widget>[
                      Text(
                          "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 3)}%  ${c3.toString()}",
                          style: widget.userChoice == 3
                              ? const TextStyle(
                                  color: Colors.indigo,
                                  fontWeight: FontWeight.bold)
                              : (lowest == v3
                                  ? widget.lowestPollStyle
                                  : widget.onVotePollStyle)),
                    ],
                  ),
                ],
              ),
              linearStrokeCap: LinearStrokeCap.roundAll,
              progressColor: lowest == v3
                  ? widget.lowestBackgroundColor
                  : widget.onVoteBackgroundColor,
              backgroundColor: Colors.white,
            ),
          ),
        if (c4 == null)
          const Offstage()
        else
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
//              width: MediaQuery.of(context).size.width,
              animation: true,
              lineHeight: 38.0,
              animationDuration: 500,
              percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 4)[0]
                  as double,
              center: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: <Widget>[
                      Text(
                        "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 4)}%  ${c4.toString()}",
                        style: widget.userChoice == 4
                            ? const TextStyle(
                                color: Colors.indigo,
                                fontWeight: FontWeight.bold)
                            : (lowest == v4
                                ? widget.lowestPollStyle
                                : widget.onVotePollStyle),
                      ),
                    ],
                  ),
                ],
              ),
              linearStrokeCap: LinearStrokeCap.roundAll,
              progressColor: lowest == v4
                  ? widget.lowestBackgroundColor
                  : widget.onVoteBackgroundColor,
              backgroundColor: Colors.white,
            ),
          ),
        if (c5 == null)
          const Offstage()
        else
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
//              width: MediaQuery.of(context).size.width,
              animation: true,
              lineHeight: 38.0,
              animationDuration: 500,
              percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 5)[0]
                  as double,
              center: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: <Widget>[
                      Text(
                          "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 5)}%  ${c5.toString()}",
                          style: widget.userChoice == 5
                              ? const TextStyle(
                                  color: Colors.indigo,
                                  fontWeight: FontWeight.bold)
                              : (lowest == v5
                                  ? widget.lowestPollStyle
                                  : widget.onVotePollStyle)),
                    ],
                  ),
                ],
              ),
              linearStrokeCap: LinearStrokeCap.roundAll,
              progressColor: lowest == v5
                  ? widget.lowestBackgroundColor
                  : widget.onVoteBackgroundColor,
              backgroundColor: Colors.white,
            ),
          ),
        if (c6 == null)
          const Offstage()
        else
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
//              width: MediaQuery.of(context).size.width,
              animation: true,
              lineHeight: 38.0,
              animationDuration: 500,
              percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 6)[0]
                  as double,
              center: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: <Widget>[
                      Text(
                          "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 6)}%  ${c6.toString()}",
                          style: widget.userChoice == 6
                              ? const TextStyle(
                                  color: Colors.indigo,
                                  fontWeight: FontWeight.bold)
                              : (lowest == v6
                                  ? widget.lowestPollStyle
                                  : widget.onVotePollStyle)),
                    ],
                  ),
                ],
              ),
              linearStrokeCap: LinearStrokeCap.roundAll,
              progressColor: lowest == v6
                  ? widget.lowestBackgroundColor
                  : widget.onVoteBackgroundColor,
              backgroundColor: Colors.white,
            ),
          ),
        if (c7 == null)
          const Offstage()
        else
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
//              width: MediaQuery.of(context).size.width,
              animation: true,
              lineHeight: 38.0,
              animationDuration: 500,
              percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 7)[0]
                  as double,
              center: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: <Widget>[
                      Text(
                        "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 7)}%  ${c7.toString()}",
                        style: widget.userChoice == 7
                            ? const TextStyle(
                                color: Colors.indigo,
                                fontWeight: FontWeight.bold)
                            : (lowest == v7
                                ? widget.lowestPollStyle
                                : widget.onVotePollStyle),
                      ),
                    ],
                  ),
                ],
              ),
              linearStrokeCap: LinearStrokeCap.roundAll,
              progressColor: lowest == v7
                  ? widget.lowestBackgroundColor
                  : widget.onVoteBackgroundColor,
              backgroundColor: Colors.white,
            ),
          ),
        if (c8 == null)
          const Offstage()
        else
          Container(
            padding: const EdgeInsets.fromLTRB(9, 0, 9, 0),
            margin: const EdgeInsets.only(bottom: 20),
            decoration: BoxDecoration(
              border: Border.all(color: Colors.grey.shade300),
              borderRadius: BorderRadius.circular(22),
            ),
            width: double.infinity,
            child: LinearPercentIndicator(
//              width: MediaQuery.of(context).size.width,
              animation: true,
              lineHeight: 38.0,
              animationDuration: 500,
              percent: PollMath.getPerc(v1, v2, v3, v4, v5, v6, v7, v8, 8)[0]
                  as double,
              center: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: <Widget>[
                  Row(
                    mainAxisAlignment: MainAxisAlignment.start,
                    children: <Widget>[
                      Text(
                          "${PollMath.getMainPerc(v1, v2, v3, v4, v5, v6, v7, v8, 8)}%  ${c8.toString()}",
                          style: widget.userChoice == 8
                              ? const TextStyle(
                                  color: Colors.indigo,
                                  fontWeight: FontWeight.bold)
                              : (lowest == v8
                                  ? widget.lowestPollStyle
                                  : widget.onVotePollStyle)),
                    ],
                  ),
                ],
              ),
              linearStrokeCap: LinearStrokeCap.roundAll,
              progressColor: lowest == v8
                  ? widget.lowestBackgroundColor
                  : widget.onVoteBackgroundColor,
              backgroundColor: Colors.white,
            ),
          ),
      ],
    );
  }

  /// simple logic to detect users choice and return a check icon
  // ignore: avoid_positional_boolean_parameters
  Widget myOwnChoice(final bool choice) {
    if (choice) {
      return const Icon(
        Icons.check_circle_outline,
        color: Colors.white,
        size: 17,
      );
    } else {
      return Container();
    }
  }
}

/// Help detect type of view user wants
enum PollsType {
  creator,
  voter,
  readOnly,
}

/// does the maths for Polls
class PollMath {
  static getMainPerc(final v1, final v2, final v3, final v4, final v5, final v6,
      final v7, final v8, final choice) {
    double div = 0;
    double slot1res = v1 as double;
    double slot2res = v2 as double;
    double slot3res = v3 == null ? 0.0 : v3 as double;
    double slot4res = v4 == null ? 0.0 : v4 as double;
    double slot5res = v5 == null ? 0.0 : v5 as double;
    double slot6res = v6 == null ? 0.0 : v6 as double;
    double slot7res = v7 == null ? 0.0 : v7 as double;
    double slot8res = v8 == null ? 0.0 : v8 as double;

    if (choice == 1) {
      final double sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = div = sum == 0 ? 0 : (100 / sum) * slot1res;
    }
    if (choice == 2) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = div = sum == 0 ? 0 : (100 / sum) * slot2res;
    }
    if (choice == 3) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = div = sum == 0 ? 0 : (100 / sum) * slot3res;
    }
    if (choice == 4) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = div = sum == 0 ? 0 : (100 / sum) * slot4res;
    }
    if (choice == 5) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = div = sum == 0 ? 0 : (100 / sum) * slot5res;
    }

    if (choice == 6) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = div = sum == 0 ? 0 : (100 / sum) * slot6res;
    }

    if (choice == 7) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = div = sum == 0 ? 0 : (100 / sum) * slot7res;
    }

    if (choice == 8) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = div = sum == 0 ? 0 : (100 / sum) * slot8res;
    }

    return div == 0 ? 0 : div.round();
  }

  static List getPerc(final v1, final v2, final v3, final v4, final v5,
      final v6, final v7, final v8, final choice) {
    double div = 0;
    double slot1res = v1 as double;
    double slot2res = v2 as double;
    double slot3res = v3 == null ? 0.0 : v3 as double;
    double slot4res = v4 == null ? 0.0 : v4 as double;
    double slot5res = v5 == null ? 0.0 : v5 as double;
    double slot6res = v6 == null ? 0.0 : v6 as double;
    double slot7res = v7 == null ? 0.0 : v7 as double;
    double slot8res = v8 == null ? 0.0 : v8 as double;

    if (choice == 1) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;

      div = sum == 0 ? 0 : (1 / sum) * slot1res;
    }
    if (choice == 2) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = sum == 0 ? 0 : (1 / sum) * slot2res;
    }
    if (choice == 3) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = sum == 0 ? 0 : (1 / sum) * slot3res;
    }
    if (choice == 4) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = sum == 0 ? 0 : (1 / sum) * slot4res;
    }

    if (choice == 5) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = sum == 0 ? 0 : (1 / sum) * slot5res;
    }

    if (choice == 6) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = sum == 0 ? 0 : (1 / sum) * slot6res;
    }

    if (choice == 7) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = sum == 0 ? 0 : (1 / sum) * slot7res;
    }

    if (choice == 8) {
      final sum = slot1res +
          slot2res +
          slot3res +
          slot4res +
          slot5res +
          slot6res +
          slot7res +
          slot8res;
      div = sum == 0 ? 0 : (1 / sum) * slot8res;
    }
    return [if (div == 0) 0.0 else div.toDouble(), div];
  }
}
