part of kitcod_uikit_flutter;

class ProfileDetails extends StatelessWidget {
  const ProfileDetails({
    required this.name,
    required this.userName,
    required this.profileImageUrl,
    required this.groupTags,
    this.feedGroupsArray,
    this.profileDetailsArray,
    this.feedPostsArray,
    this.nameStyle,
    this.userNameStyle,
    this.groupTagsStyle,
    this.postedTo,
    final Key? key,
  }) : super(key: key);
  // -------------------------------- VARIABLES -------------------------------- //

  final List<String> groupTags;
  final String profileImageUrl;
  final String name;
  final String userName;
  final String? postedTo;
  final TextStyle? nameStyle;
  final TextStyle? groupTagsStyle;
  final TextStyle? userNameStyle;
  final List<FeedGroup>? feedGroupsArray;
  final List<FeedPost>? feedPostsArray;
  final List<ProfileProperties>? profileDetailsArray;

  // -------------------------------- BUILD FUNCTION -------------------------------- //

  @override
  SizedBox build(final BuildContext context) => SizedBox(
      width: MediaQuery.of(context).size.width,
      child: Row(
        children: [
          CircleAvatar(
            radius: 23,
            backgroundImage: NetworkImage(profileImageUrl),
            backgroundColor: Colors.transparent,
          ),
          Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.start,
            children: [
              Padding(
                padding: const EdgeInsets.only(left: 10),
                child: RichText(
                  text: TextSpan(
                      text: name,
                      style: nameStyle ??
                          const TextStyle(
                              fontSize: 15,
                              fontWeight: FontWeight.bold,
                              color: Colors.black),
                      children: <TextSpan>[
                        TextSpan(
                          text: " $userName",
                          style: userNameStyle ??
                              const TextStyle(
                                  fontSize: 15,
                                  color: Colors.grey,
                                  fontWeight: FontWeight.normal),
                        )
                      ]),
                ),
              ),
              const SizedBox(height: 3),
              FutureBuilder(
                  future: KitcodApi.instance.getGroupsData(),
                  // ignore: avoid_types_on_closure_parameters
                  builder: (final context, final snapshot) {
                    if (!snapshot.hasData) {
                      return const Padding(
                          padding: EdgeInsets.only(left: 10),
                          child: Text("Loading..."));
                    } else {
                      if (snapshot.hasError) {
                        return Center(child: Text("Error: ${snapshot.error}"));
                      } else {
                        final List<CommunitiesList> communitiesList =
                            snapshot.data! as List<CommunitiesList>;
                        return feedGroupsArray == null
                            ? Container(
                                padding: const EdgeInsets.only(left: 10),
                                width: MediaQuery.of(context).size.width * 0.6,
                                child: Wrap(
                                  children: <Widget>[
                                    if (postedTo != null)
                                      Text(postedTo!,
                                          style: const TextStyle(
                                              color: Colors.grey)),
                                    for (var tag in groupTags)
                                      Text(communitiesList[0].name,
                                          style: groupTagsStyle ??
                                              const TextStyle(
                                                  color: Colors.indigo))
                                  ],
                                ),
                              )
                            : TextButton(
                                style: TextButton.styleFrom(
                                  minimumSize: Size.zero,
                                  padding: EdgeInsets.zero,
                                  tapTargetSize:
                                      MaterialTapTargetSize.shrinkWrap,
                                ),
                                onPressed: () {
                                  Navigator.push(
                                    context,
                                    MaterialPageRoute(
                                        builder: (final context) => GroupPage(
                                              groupImageUrl: communitiesList[0]
                                                          .media
                                                          .proImg ==
                                                      null
                                                  ? "https://picsum.photos/201"
                                                  : communitiesList[0]
                                                      .media
                                                      .proImg!
                                                      .resizedMediaList
                                                      .first
                                                      .mediaUrl,
                                              groupTitle:
                                                  communitiesList[0].name,
                                              members: communitiesList[0]
                                                          .rangeMembersCount ==
                                                      null
                                                  ? ""
                                                  : communitiesList[0]
                                                      .rangeMembersCount
                                                      .toString(),
                                              membersListUrl:
                                                  feedGroupsArray![0]
                                                      .membersImageUrls,
                                              groupPageAbout: communitiesList[0]
                                                  .description,
                                              groupPosts: feedGroupsArray![0]
                                                  .groupPosts!,
                                              groupPageStatus: "Open group",
                                              isJoined: true,
                                              feedGroupsArray: feedGroupsArray!,
                                              feedPostsArray: feedPostsArray!,
                                              profileDetailsArray:
                                                  profileDetailsArray!,
                                            )),
                                  );
                                },
                                child: Container(
                                  padding: const EdgeInsets.only(left: 10),
                                  width:
                                      MediaQuery.of(context).size.width * 0.6,
                                  child: Wrap(
                                    children: <Widget>[
                                      if (postedTo != null)
                                        Text(postedTo!,
                                            style: const TextStyle(
                                                color: Colors.grey)),
                                      for (var tag in groupTags)
                                        Text(communitiesList[0].name,
                                            style: groupTagsStyle ??
                                                const TextStyle(
                                                    color: Colors.indigo))
                                    ],
                                  ),
                                ),
                              );
                      }
                    }
                  })
            ],
          ),
        ],
      ));
}
