part of kitcod_uikit_flutter;

class TextIconButton extends StatelessWidget {
  const TextIconButton({
    required this.icon,
    required this.text,
    required this.selectedColor,
    required this.disabledColor,
    this.width,
    this.textStyle,
    this.margin,
    this.onPressed,
    this.isSelected = false,
    final Key? key,
  }) : super(key: key);
  final IconData icon;
  final String text;
  final TextStyle? textStyle;
  final Color selectedColor;
  final Color disabledColor;
  final bool isSelected;
  final EdgeInsets? margin;
  final VoidCallback? onPressed;
  final double? width;

  Color _getColor() => isSelected ? selectedColor : disabledColor;

  @override
  GestureDetector build(final context) => GestureDetector(
        onTap: onPressed,
        child: AnimatedContainer(
          width: width ?? MediaQuery.of(context).size.width * 0.3,
          margin: margin,
          duration: const Duration(milliseconds: 200),
          decoration: BoxDecoration(
            border: Border.all(
                color: isSelected ? selectedColor : Colors.transparent),
            borderRadius: BorderRadius.circular(12),
            color: _getColor().withOpacity(0.15),
          ),
          child: Padding(
            padding: const EdgeInsets.all(12),
            child: Column(
              mainAxisSize: MainAxisSize.min,
              children: [
                Icon(icon, color: _getColor()),
                const SizedBox(height: 5, width: 70),
                Text(
                  text,
                  style: textStyle != null
                      ? textStyle!.apply(color: _getColor())
                      : const TextStyle().apply(color: _getColor()),
                )
              ],
            ),
          ),
        ),
      );
}
