part of kitcod_uikit_flutter;

class CreateGroupCommunity extends StatefulWidget {
  const CreateGroupCommunity(
      {required this.headerView,
      required this.heading,
      required this.description,
      this.headingStyle,
      this.descriptionStyle,
      this.optionIconColor,
      this.selectedColor,
      this.disabledColor,
      this.addIconColor,
      this.addIconTextStyle,
      this.optionTitleStyle,
      this.optionDescriptionStyle,
      this.bottomButtonColor,
      this.bottomButtonBorderColor,
      this.bottomButtonStyle,
      final Key? key})
      : super(key: key);
  final HeaderView headerView;
  final String heading;
  final String description;
  final TextStyle? headingStyle;
  final TextStyle? descriptionStyle;
  final Color? optionIconColor;
  final Color? selectedColor;
  final Color? disabledColor;
  final Color? addIconColor;
  final TextStyle? optionTitleStyle;
  final TextStyle? optionDescriptionStyle;
  final TextStyle? addIconTextStyle;
  final Color? bottomButtonColor;
  final Color? bottomButtonBorderColor;
  final TextStyle? bottomButtonStyle;

  @override
  State<CreateGroupCommunity> createState() => _CreateGroupCommunityState();
}

class _CreateGroupCommunityState extends State<CreateGroupCommunity> {
  // -------------------------------- VARIABLES -------------------------------- //
  late bool isPublic;

  // -------------------------------- LIFECYCLE FUNCTIONS -------------------------------- //
  @override
  void initState() {
    super.initState();
    isPublic = true;
  }

  // -------------------------------- UI FUNCTIONS -------------------------------- //
  Padding _addIcons() => Padding(
        padding: const EdgeInsets.all(8),
        child: Row(children: [
          Icon(Icons.sentiment_satisfied_alt_rounded,
              color: widget.addIconColor ?? Colors.grey),
          const SizedBox(width: 5),
          Text("Add Icon",
              style: widget.addIconTextStyle ??
                  const TextStyle(color: Colors.grey)),
          const SizedBox(width: 5),
          Icon(Icons.photo_size_select_actual_outlined,
              color: widget.addIconColor ?? Colors.grey),
          const SizedBox(width: 5),
          Text("Add Cover",
              style: widget.addIconTextStyle ??
                  const TextStyle(color: Colors.grey)),
        ]),
      );

  Flexible _superGroupTextField() => Flexible(
        child: TextField(
          textAlignVertical: TextAlignVertical.center,
          cursorColor: Colors.indigoAccent,
          maxLength: kCreateGroupMaxCharactersLength,
          decoration: kKitCodUIKitTextFieldStyle.copyWith(
              hintText: "What's the name of your group?"),
          onChanged: (final value) {},
        ),
      );

  Column _groupPrivacyButtons() => Column(
        crossAxisAlignment: CrossAxisAlignment.start,
        mainAxisSize: MainAxisSize.min,
        children: [
          const SizedBox(height: 8),
          Text(
            widget.heading,
            style: widget.headingStyle ??
                const TextStyle(fontWeight: FontWeight.w600, fontSize: 16),
          ),
          const SizedBox(height: 5),
          Text(
            widget.description,
            style: widget.descriptionStyle ??
                const TextStyle(
                    fontWeight: FontWeight.w600,
                    fontSize: 14,
                    color: Colors.grey),
          ),
          const SizedBox(height: 16),
          Row(
            children: [
              TextIconButtonDetailed(
                icon: Icons.check_circle,
                text: "Open",
                selectedColor: widget.selectedColor ?? Colors.red,
                disabledColor: widget.disabledColor ?? Colors.grey.shade200,
                isSelected: isPublic,
                description: "Anyone can join this public group",
                width: MediaQuery.of(context).size.width * 0.42,
                onPressed: () => setState(() => isPublic = true),
                optionDescriptionStyle: widget.optionDescriptionStyle,
                optionIconColor: widget.optionIconColor,
                optionTitleStyle: widget.optionTitleStyle,
              ),
              const SizedBox(width: 12),
              TextIconButtonDetailed(
                icon: Icons.shield_sharp,
                text: "Accept Application",
                selectedColor: widget.selectedColor ?? Colors.red,
                disabledColor: widget.disabledColor ?? Colors.grey.shade200,
                isSelected: !isPublic,
                description:
                    "Anyone can apply to join. You can choose who to accept.",
                width: MediaQuery.of(context).size.width * 0.42,
                onPressed: () => setState(() => isPublic = false),
                optionDescriptionStyle: widget.optionDescriptionStyle,
                optionIconColor: widget.optionIconColor,
                optionTitleStyle: widget.optionTitleStyle,
              ),
            ],
          )
        ],
      );

  SizedBox _aboutTheGroupTextField() => SizedBox(
        height: 150,
        child: TextField(
          textAlignVertical: TextAlignVertical.center,
          cursorColor: Colors.indigoAccent,
          maxLines: 20,
          decoration: kKitCodUIKitTextFieldStyle.copyWith(
            hintText: "About the group (optional)",
            contentPadding:
                const EdgeInsets.symmetric(vertical: 16, horizontal: 12),
          ),
          onChanged: (final value) {},
        ),
      );

  Button _bottomButton() => Button(
      name: "Create Group",
      width: MediaQuery.of(context).size.width * 0.9,
      backgroundColor: widget.bottomButtonColor ?? kUIKitCodAccentColor,
      borderSide: BorderSide(
          color: widget.bottomButtonBorderColor ?? kUIKitCodAccentColor),
      textStyle: widget.bottomButtonStyle ??
          const TextStyle(color: Colors.white, fontSize: 16),
      onPressed: () {});

  // -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  Widget build(final context) => Scaffold(
        appBar: widget.headerView,
        body: SafeArea(
          child: Container(
            padding: const EdgeInsets.symmetric(vertical: 12, horizontal: 20),
            child: Column(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              mainAxisSize: MainAxisSize.min,
              children: [
                Column(
                  mainAxisSize: MainAxisSize.min,
                  children: [
                    const SizedBox(height: 16),
                    _addIcons(),
                    _superGroupTextField(),
                    const SizedBox(height: 24),
                    _groupPrivacyButtons(),
                    const SizedBox(height: 24),
                    _aboutTheGroupTextField(),
                  ],
                ),
                const Spacer(),
                _bottomButton(),
              ],
            ),
          ),
        ),
      );
}
