// ignore_for_file: avoid_dynamic_calls

part of kitcod_uikit_flutter;

class DiscoverGroups extends StatelessWidget {
  const DiscoverGroups({
    required this.headerView,
    required this.groupsList,
    required this.feedPostsArray,
    required this.feedGroupsArray,
    required this.profileDetailsArray,
    this.groupCardTitleStyle,
    this.groupCardMembersStyle,
    this.groupCardButtonColor,
    this.groupCardButtonStyle,
    this.groupPageTitleStyle,
    this.groupPageMembersStyle,
    this.groupPageStatusStyle,
    this.groupPageAboutStyle,
    this.groupCardWidth,
    this.groupCardHeight,
    this.avatarSize,
    final Key? key,
  }) : super(key: key);
  // -------------------------------- VARIABLES -------------------------------- //

  final HeaderView headerView;
  final List<FeedGroup> groupsList;
  final TextStyle? groupCardTitleStyle;
  final TextStyle? groupCardMembersStyle;
  final TextStyle? groupCardButtonStyle;
  final Color? groupCardButtonColor;
  final TextStyle? groupPageTitleStyle;
  final TextStyle? groupPageMembersStyle;
  final TextStyle? groupPageStatusStyle;
  final TextStyle? groupPageAboutStyle;
  final double? groupCardWidth;
  final double? groupCardHeight;
  final double? avatarSize;
  final List<FeedPost> feedPostsArray;
  final List<FeedGroup> feedGroupsArray;
  final List<ProfileProperties> profileDetailsArray;

  // -------------------------------- UI FUNCTIONS -------------------------------- //

  Container _headerWidget(final BuildContext context) => Container(
        padding: const EdgeInsets.all(10),
        child: Wrap(
          children: [
            FutureBuilder(
              future: KitcodApi.instance.getGroupsData(),
              // ignore: avoid_types_on_closure_parameters
              builder: (final context, final AsyncSnapshot<Object> snapshot) {
                if (!snapshot.hasData) {
                  return const Center(child: Text("Loading..."));
                } else {
                  if (snapshot.hasError) {
                    return Center(child: Text("Error: ${snapshot.error}"));
                  } else {
                    final List<CommunitiesList> communitiesList =
                        snapshot.data! as List<CommunitiesList>;
                    return GridView.builder(
                      shrinkWrap: true,
                      physics: const NeverScrollableScrollPhysics(),
                      itemCount: communitiesList.length,
                      gridDelegate:
                          const SliverGridDelegateWithFixedCrossAxisCount(
                        crossAxisCount: 2,
                        childAspectRatio: 0.59,
                      ),
                      itemBuilder: (final context, final i) => GroupCards(
                        feedGroupsArray: feedGroupsArray,
                        feedPostsArray: feedPostsArray,
                        profileDetailsArray: profileDetailsArray,
                        groupCardWidth: groupCardWidth,
                        groupCardHeight: groupCardHeight,
                        avatarSize: avatarSize,
                        groupImageUrl: communitiesList[i].media.proImg == null
                            ? "https://picsum.photos/201"
                            : communitiesList[i]
                                .media
                                .proImg!
                                .resizedMediaList
                                .first
                                .mediaUrl,
                        groupTitle:
                            communitiesList[i].name, // groupItem.groupTitle,
                        members: communitiesList[i].rangeMembersCount == null
                            ? ""
                            : communitiesList[i]
                                .rangeMembersCount
                                .toString(), //groupItem.members,
                        membersListUrl: groupsList[0]
                            .membersImageUrls, //  groupItem.membersImageUrls,
                        groupPageAbout: communitiesList[i]
                            .description, //groupItem.groupAbout!,
                        groupPosts:
                            groupsList[0].groupPosts!, // groupItem.groupPosts!,
                        groupPageStatus: "Open Group", //groupItem.groupStatus!,
                        isJoined: false, // groupItem.isJoined!,
                        groupCardButtonColor: groupCardButtonColor,
                        groupCardButtonStyle: groupCardButtonStyle,
                        groupCardTitleStyle: groupCardTitleStyle,
                        groupCardMembersStyle: groupCardMembersStyle,
                        groupPageAboutStyle: groupPageAboutStyle,
                        groupPageStatusStyle: groupPageStatusStyle,
                        groupPageTitleStyle: groupPageTitleStyle,
                        groupPageMembersStyle: groupPageMembersStyle,
                      ),
                    );
                  }
                }
              },
            ),
          ],
        ),
      );

  // -------------------------------- BUILD FUNCTION -------------------------------- //
  @override
  Widget build(final context) => Scaffold(
        appBar: headerView,
        body: SingleChildScrollView(
          child: Column(children: [
            _headerWidget(context),
          ]),
        ),
      );
}
